RawAdapter

Struct RawAdapter 

pub struct RawAdapter<A> { /* private fields */ }
Adapter around a raw, interleaved, f32 PCM byte stream.

This may be used to port legacy songbird audio sources to be compatible with the symphonia backend, particularly those with unknown length (making WAV unsuitable).

The format is described in RawReader.

Implementations

Source

impl<A: MediaSource> RawAdapter<A>

pub fn new(audio_source: A, sample_rate: u32, channel_count: u32) -> Self

Wrap an input PCM byte source to be readable by symphonia.