pub struct RawAdapter<A> { /* private fields */ }Expand description
Adapter around a raw, interleaved, f32 PCM byte stream.
This may be used to port legacy songbird audio sources to be compatible with the symphonia backend, particularly those with unknown length (making WAV unsuitable).
The format is described in RawReader.
Implementations